@@ -3,19 +3,21 @@
 
     Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
@@ -26,6 +28,8 @@
 #include <QEvent>
 #include <kconfiggroup.h>
 
+#include "processcore/processcore_debug.h"
+
 #include "SensorShellAgent.h"
 #include "SensorSocketAgent.h"
 
@@ -251,7 +255,7 @@ bool SensorManager::engage( const QString &hostName, const QString &shell,
     else
       agent = new SensorSocketAgent( this );
 
-    if ( !agent->start( hostName.toAscii(), shell, command, port ) ) {
+    if ( !agent->start( hostName.toLatin1(), shell, command, port ) ) {
       delete agent;
       return false;
     }
@@ -303,7 +307,7 @@ bool SensorManager::resynchronize( const QString &hostName )
 
   mAgents.remove( hostName );
 
-  qDebug() << "Re-synchronizing connection to " << hostName;
+  qCDebug(LIBKSYSGUARD) << "Re-synchronizing connection to " << hostName;
 
   return engage( hostName, shell, command );
 }
@@ -426,4 +430,4 @@ void SensorManager::disconnectClient( SensorClient *client )
     it.next().value()->disconnectClient( client );
 }
 
-#include "SensorManager.moc"
+
