@@ -1,21 +1,21 @@
 /*
-    This file is part of the KDE project
+ Copyright (c) 2006 - 2009 John Tapsell <tapsell@kde.org>
 
-    Copyright (c) 2006 - 2009 John Tapsell <tapsell@kde.org>
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
@@ -30,6 +30,7 @@
 #endif
 
 #include "ksignalplotter_p.h"
+#include "processcore/processcore_debug.h"
 
 #include <math.h>  //For floor, ceil, log10 etc for calculating ranges
 
@@ -38,6 +39,7 @@
 #include <QPainterPath>
 #include <QPaintEvent>
 #include <QEvent>
+#include <QDebug>
 
 #ifdef GRAPHICS_SIGNAL_PLOTTER
 #include <QGraphicsSceneResizeEvent>
@@ -45,9 +47,7 @@
 #include <Plasma/Theme>
 #endif
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kiconloader.h>
 #include <math.h>
 #include <limits>
@@ -111,11 +111,11 @@ QColor KSignalPlotter::beamColor( int index ) const {
 
 void KSignalPlotter::setBeamColor( int index, const QColor &color ) {
     if(!color.isValid()) {
-        kDebug(1215) << "Invalid color";
+        qCDebug(LIBKSYSGUARD) << "Invalid color";
         return;
     }
     if( index >= d->mBeamColors.count() ) {
-        kDebug(1215) << "Invalid index" << index;
+        qCDebug(LIBKSYSGUARD) << "Invalid index" << index;
         return;
     }
     Q_ASSERT(d->mBeamColors.count() == d->mBeamColorsLight.count());
@@ -517,7 +517,7 @@ void KSignalPlotterPrivate::rescale() {
 void KSignalPlotterPrivate::addSample( const QList<qreal>& sampleBuf )
 {
     if(sampleBuf.count() != mBeamColors.count()) {
-        kDebug(1215) << "Sample data discarded - contains wrong number of beams";
+        qCDebug(LIBKSYSGUARD) << "Sample data discarded - contains wrong number of beams";
         return;
     }
     mBeamData.prepend(sampleBuf);
@@ -553,7 +553,7 @@ void KSignalPlotterPrivate::reorderBeams( const QList<int>& newOrder )
     QList< QList<qreal> >::Iterator it;
     for(it = mBeamData.begin(); it != mBeamData.end(); ++it) {
         if(newOrder.count() != (*it).count()) {
-            kWarning(1215) << "Serious problem in move sample.  beamdata[i] has " << (*it).count() << " and neworder has " << newOrder.count();
+            qCWarning(LIBKSYSGUARD) << "Serious problem in move sample.  beamdata[i] has " << (*it).count() << " and neworder has " << newOrder.count();
         } else {
             QList<qreal> newBeam;
             for(int i = 0; i < newOrder.count(); i++) {
